@@ -1,3 +1,4 @@
+# 1 "src/batArray.mliv"
 (*
  * BatArray - additional and modified functions for arrays.
  * Copyright (C) 1996 Xavier Leroy
@@ -82,13 +83,18 @@ external make : int -> 'a -> 'a array = "caml_make_vect"
     If the value of [x] is a floating-point number, then the maximum
     size is only [Sys.max_array_length / 2].*)
 
+# 87 "src/batArray.mliv"
 
-external make_float : int -> float array = "caml_make_float_vect"
+# 90 "src/batArray.mliv"
+
+external create_float: int -> float array = "caml_make_float_vect"
+val make_float: int -> float array
+# 93 "src/batArray.mliv"
 (** [Array.make_float n] returns a fresh float array of length [n],
-    with uninitialized data.
+   with uninitialized data.
 
-    @since 2.3.0 and OCaml 4.2.0
- *)
+   @since 2.3.0
+*)
 
 external create : int -> 'a -> 'a array = "caml_make_vect"
 (** @deprecated [Array.create] is an alias for {!Array.make}. *)
@@ -632,8 +638,8 @@ sig
   external make : int -> 'a -> ('a, _) t = "caml_make_vect"
   external create : int -> 'a -> ('a, _) t = "caml_make_vect"
 
-
   external make_float : int -> (float, _) t = "caml_make_float_vect"
+# 643 "src/batArray.mliv"
 (** [Array.make_float n] returns a fresh float array of length [n],
     with uninitialized data.
 
