@@ -1,3 +1,4 @@
+# 1 "src/batBigarray.mliv"
 (*
  * BatBigarray - additional and modified functions for big arrays.
  * Copyright (C) 2000 Michel Serrano
@@ -85,28 +86,40 @@
    we need to explicitly equate each type with its constructor *)
 type float32_elt = Bigarray.float32_elt
  = Float32_elt
+# 88 "src/batBigarray.mliv"
 type float64_elt = Bigarray.float64_elt
  = Float64_elt
+# 90 "src/batBigarray.mliv"
 type complex32_elt = Bigarray.complex32_elt
  = Complex32_elt
+# 92 "src/batBigarray.mliv"
 type complex64_elt = Bigarray.complex64_elt
  = Complex64_elt
+# 94 "src/batBigarray.mliv"
 type int8_signed_elt = Bigarray.int8_signed_elt
  = Int8_signed_elt
+# 96 "src/batBigarray.mliv"
 type int8_unsigned_elt = Bigarray.int8_unsigned_elt
  = Int8_unsigned_elt
+# 98 "src/batBigarray.mliv"
 type int16_signed_elt = Bigarray.int16_signed_elt
  = Int16_signed_elt
+# 100 "src/batBigarray.mliv"
 type int16_unsigned_elt = Bigarray.int16_unsigned_elt
  = Int16_unsigned_elt
+# 102 "src/batBigarray.mliv"
 type int_elt = Bigarray.int_elt
  = Int_elt
+# 104 "src/batBigarray.mliv"
 type int32_elt = Bigarray.int32_elt
  = Int32_elt
+# 106 "src/batBigarray.mliv"
 type int64_elt = Bigarray.int64_elt
  = Int64_elt
+# 108 "src/batBigarray.mliv"
 type nativeint_elt = Bigarray.nativeint_elt
  = Nativeint_elt
+# 110 "src/batBigarray.mliv"
 
 type ('a, 'b) kind = ('a,'b) Bigarray.kind
            = Float32 : (float, float32_elt) kind
@@ -122,6 +135,7 @@ type ('a, 'b) kind = ('a,'b) Bigarray.kind
            | Complex32 : (Complex.t, complex32_elt) kind
            | Complex64 : (Complex.t, complex64_elt) kind
            | Char : (char, int8_unsigned_elt) kind
+# 125 "src/batBigarray.mliv"
 (** To each element kind is associated an OCaml type, which is
     the type of OCaml values that can be stored in the big array
     or read back from it.  This type is not necessarily the same
@@ -131,12 +145,6 @@ type ('a, 'b) kind = ('a,'b) Bigarray.kind
     its elements from OCaml uses the OCaml type [float], which is
     64-bit double precision floats.
 
-
-
-
-
-
-
    The GADT type [('a, 'b) kind] captures this association
    of an OCaml type ['a] for values read or written in the big array,
    and of an element kind ['b] which represents the actual contents
@@ -157,6 +165,7 @@ type ('a, 'b) kind = ('a,'b) Bigarray.kind
     | Int -> 0 | Nativeint -> 0n
     | Char -> '\000'
 ]}
+# 160 "src/batBigarray.mliv"
 *)
 
 
@@ -212,14 +221,22 @@ val char : (char, int8_unsigned_elt) kind
     characters instead of arrays of small integers, by using
     the kind value [char] instead of [int8_unsigned]. *)
 
+val kind_size_in_bytes : ('a, 'b) kind -> int
+(** [kind_size_in_bytes k] is the number of bytes used to store
+   an element of type [k].
+
+   @since 2.5.0 *)
+
 (** {6 Array layouts} *)
 
 type c_layout = Bigarray.c_layout
  = C_layout_typ
+# 225 "src/batBigarray.mliv"
 (** See {!Bigarray.fortran_layout}.*)
 
 type fortran_layout = Bigarray.fortran_layout
  = Fortran_layout_typ
+# 229 "src/batBigarray.mliv"
 (** To facilitate interoperability with existing C and Fortran code,
     this library supports two different memory layouts for big arrays,
     one compatible with the C conventions,
@@ -245,6 +262,7 @@ type fortran_layout = Bigarray.fortran_layout
 type 'a layout = 'a Bigarray.layout
            = C_layout : c_layout layout
            | Fortran_layout : fortran_layout layout
+# 254 "src/batBigarray.mliv"
 (** The type ['a layout] represents one of the two supported
     memory layouts: C-style if ['a] is {!Bigarray.c_layout}, Fortran-style
     if ['a] is {!Bigarray.fortran_layout}. *)
@@ -329,6 +347,12 @@ sig
   external layout: ('a, 'b, 'c) t -> 'c layout = "caml_ba_layout"
   (** Return the layout of the given big array. *)
 
+  val size_in_bytes : ('a, 'b, 'c) t -> int
+  (** [size_in_bytes a] is the number of elements in [a] multiplied
+    by [a]'s {!kind_size_in_bytes}.
+
+   @since 2.5.0 *)
+
   external get: ('a, 'b, 'c) t -> int array -> 'a = "caml_ba_get_generic"
   (** Read an element of a generic big array.
     [Genarray.get a [|i1; ...; iN|]] returns the element of [a]
@@ -556,8 +580,8 @@ module Array1 : sig
       determine the array element kind and the array layout
       as described for [Genarray.create]. *)
 
-
   external dim: ('a, 'b, 'c) t -> int = "%caml_ba_dim_1"
+# 573 "src/batBigarray.mliv"
   (** Return the size (dimension) of the given one-dimensional
       big array. *)
 
@@ -567,6 +591,12 @@ module Array1 : sig
   external layout: ('a, 'b, 'c) t -> 'c layout = "caml_ba_layout"
   (** Return the layout of the given big array. *)
 
+  val size_in_bytes : ('a, 'b, 'c) t -> int
+  (** [size_in_bytes a] is the number of elements in [a] multiplied
+    by [a]'s {!kind_size_in_bytes}.
+
+   @since 2.5.0 *)
+
   external get: ('a, 'b, 'c) t -> int -> 'a = "%caml_ba_ref_1"
   (** [Array1.get a x], or alternatively [a.{x}],
       returns the element of [a] at index [x].
@@ -684,12 +714,12 @@ sig
       determine the array element kind and the array layout
       as described for {!Bigarray.Genarray.create}. *)
 
-
   external dim1: ('a, 'b, 'c) t -> int = "%caml_ba_dim_1"
+# 707 "src/batBigarray.mliv"
   (** Return the first dimension of the given two-dimensional big array. *)
 
-
   external dim2: ('a, 'b, 'c) t -> int = "%caml_ba_dim_2"
+# 711 "src/batBigarray.mliv"
   (** Return the second dimension of the given two-dimensional big array. *)
 
   external kind: ('a, 'b, 'c) t -> ('a, 'b) kind = "caml_ba_kind"
@@ -698,6 +728,12 @@ sig
   external layout: ('a, 'b, 'c) t -> 'c layout = "caml_ba_layout"
   (** Return the layout of the given big array. *)
 
+  val size_in_bytes : ('a, 'b, 'c) t -> int
+  (** [size_in_bytes a] is the number of elements in [a] multiplied
+    by [a]'s {!kind_size_in_bytes}.
+
+   @since 2.5.0 *)
+
   external get: ('a, 'b, 'c) t -> int -> int -> 'a = "%caml_ba_ref_2"
   (** [Array2.get a x y], also written [a.{x,y}],
       returns the element of [a] at coordinates ([x], [y]).
@@ -825,16 +861,16 @@ sig
       [kind] and [layout] determine the array element kind and
       the array layout as described for {!Bigarray.Genarray.create}. *)
 
-
   external dim1: ('a, 'b, 'c) t -> int = "%caml_ba_dim_1"
+# 854 "src/batBigarray.mliv"
   (** Return the first dimension of the given three-dimensional big array. *)
 
-
   external dim2: ('a, 'b, 'c) t -> int = "%caml_ba_dim_2"
+# 858 "src/batBigarray.mliv"
   (** Return the second dimension of the given three-dimensional big array. *)
 
-
   external dim3: ('a, 'b, 'c) t -> int = "%caml_ba_dim_3"
+# 862 "src/batBigarray.mliv"
   (** Return the third dimension of the given three-dimensional big array. *)
 
   external kind: ('a, 'b, 'c) t -> ('a, 'b) kind = "caml_ba_kind"
@@ -843,6 +879,12 @@ sig
   external layout: ('a, 'b, 'c) t -> 'c layout = "caml_ba_layout"
   (** Return the layout of the given big array. *)
 
+  val size_in_bytes : ('a, 'b, 'c) t -> int
+  (** [size_in_bytes a] is the number of elements in [a] multiplied
+    by [a]'s {!kind_size_in_bytes}.
+
+   @since 2.5.0 *)
+
   external get: ('a, 'b, 'c) t -> int -> int -> int -> 'a = "%caml_ba_ref_3"
   (** [Array3.get a x y z], also written [a.{x,y,z}],
       returns the element of [a] at coordinates ([x], [y], [z]).
