@@ -580,10 +580,30 @@ val merge : ('a -> 'a -> bool) -> 'a t -> 'a t -> 'a t
     in increasing order, then [merge (<) a b] will also be sorted.
 *)
 
+val interleave : 'a t array -> 'a t
+(** [interleave enums] creates a new enumeration from an array of enumerations.
+    The new enumeration first yields the first elements of the enumerations in
+    the supplied order, then second elements, etc.  Thus, a sequence
+    [ [| [x11 ; x12 ; ...] ; [x21 ; x22, ...] , ... [xN1 ; xN2 ; ...] |] ] becomes
+    [[ x11 ; x12 ; ... ; xN1 ; x21 ; x22 ; ... ; xN2 ; x31 ; ... ]].
+*)
+
 val uniq : 'a t -> 'a t
 (** [uniq e] returns a duplicate of [e] with repeated values
-    omitted. (similar to unix's [uniq] command)
-    It uses physical equality to compare consecutive elements. *)
+    omitted (similar to unix's [uniq] command).
+    It uses structural equality to compare consecutive elements. *)
+
+val uniqq : 'a t -> 'a t
+(** [uniqq e] behaves as [uniq e] except it uses physical equality
+    to compare consecutive elements.
+
+    @since 2.4.0 *)
+
+val uniq_by : ('a -> 'a -> bool) -> 'a t -> 'a t
+(** [uniqq cmp e] behaves as [uniq e] except it allows to specify a
+    comparison function.
+
+    @since 2.4.0 *)
 
 val switch : ('a -> bool) -> 'a t -> 'a t * 'a t
 (** [switch test enum] splits [enum] into two enums, where the first enum have
@@ -834,6 +854,7 @@ module Labels : sig
   val init:       int -> f:(int -> 'a) -> 'a t
   val switch:     f:('a -> bool) -> 'a t -> 'a t * 'a t
   val compare:    ?cmp:('a -> 'a -> int) -> 'a t -> 'a t -> int
+  val uniq:       ?cmp:('a -> 'a -> bool) -> 'a t -> 'a t
 
   module LExceptionless : sig
     val find : f:('a -> bool) -> 'a t -> 'a option
