@@ -93,7 +93,7 @@ val length : 'a list -> int
 
 val at : 'a list -> int -> 'a
 (** [at l n] returns the n-th element of the list [l] or
-    @raise Invalid_argument is the index is outside of [l] bounds.  O(l) *)
+    @raise Invalid_argument if the index is outside of [l] bounds.  O(l) *)
 
 val rev : 'a list -> 'a list
 (** List reversal. *)
@@ -128,6 +128,13 @@ val make : int -> 'a -> 'a list
 (** Similar to [String.make], [make n x] returns a
     list containing [n] elements [x]. *)
 
+val range : int -> [< `To | `Downto ] -> int -> int list
+(** [range 1 `To 3] = [[1; 2; 3]].
+    [range 3 `Downto 1] = [[3; 2; 1]].
+    @raise Invalid_argument in ([range i `To j]) if (i > j).
+    @raise Invalid_argument in ([range i `Downto j]) if (i < j).
+    @since 2.2.0 *)
+
 val init : int -> (int -> 'a) -> 'a list
 (** Similar to [Array.init], [init n f] returns the list containing
     the results of (f 0),(f 1).... (f (n-1)).
@@ -146,15 +153,26 @@ val unfold: 'b -> ('b -> ('a * 'b) option) -> 'a list
     @since 2.1
 *)
 
+val unfold_exc : (unit -> 'a) -> 'a list * exn
+(** Creates a list containing the results of sequential calls
+    to [f()]. [f()] is called repeatedly until it throws an exception.
+    Both the results list, as well as the exception
+    thrown are returned in a [(results_list, exn)] pair.
+    Warning: if calls to [f()] never throw an exception, unfold_exc
+    is an infinite loop.
+
+    @since 2.3.0
+*)
+
 (**{6 Iterators}*)
 
 val iter : ('a -> unit) -> 'a list -> unit
-(** [List.iter f [a1; ...; an]] applies function [f] in turn to
-    [a1; ...; an]. It is equivalent to
-    [begin f a1; f a2; ...; f an; () end]. *)
+(** [List.iter f [a0; a1; ...; an]] applies function [f] in turn to
+    [a0; a1; ...; an]. It is equivalent to
+    [begin f a0; f a1; ...; f an; () end]. *)
 
 val iteri : (int -> 'a -> unit) -> 'a list -> unit
-(** [iteri f l] will call [(f 0 a0);(f 1 a1) ... (f n an)] where
+(** [iteri f l] will call [(f 0 a0); (f 1 a1) ... (f n an)] where
     [a0..an] are the elements of the list [l]. *)
 
 val map : ('a -> 'b) -> 'a list -> 'b list
@@ -171,17 +189,31 @@ val rev_map : ('a -> 'b) -> 'a list -> 'b list
 
 val mapi : (int -> 'a -> 'b) -> 'a list -> 'b list
 (** [mapi f l] will build the list containing
-    [(f 0 a0);(f 1 a1) ... (f n an)] where [a0..an] are the elements of
+    [(f 0 a0); (f 1 a1) ... (f n an)] where [a0..an] are the elements of
     the list [l]. *)
 
 val fold_left : ('a -> 'b -> 'a) -> 'a -> 'b list -> 'a
-(** [List.fold_left f a [b1; ...; bn]] is
-    [f (... (f (f a b1) b2) ...) bn]. *)
+(** [List.fold_left f a [b0; b1; ...; bn]] is
+    [f (... (f (f a b0) b1) ...) bn]. *)
+
+val fold_lefti : ('a -> int -> 'b -> 'a) -> 'a -> 'b list -> 'a
+(** As [fold_left], but with the index of the element, from [0] to
+    [length li - 1], as additional argument.
+
+    @since 2.3.0
+*)
 
 val fold_right : ('a -> 'b -> 'b) -> 'a list -> 'b -> 'b
 (** [List.fold_right f [a0; a1; ...; an] b] is
     [f a0 (f a1 (... (f an b) ...))].  Tail-recursive. *)
 
+val fold_righti : (int -> 'b -> 'a -> 'a) -> 'b list -> 'a -> 'a
+(** As [fold_right], but with the index of the element, from [0] to
+    [length li - 1], as additional argument.
+
+    @since 2.3.0
+*)
+
 val reduce : ('a -> 'a -> 'a) -> 'a list -> 'a
 (** [List.reduce f h::t] is [fold_left f h t].
 
@@ -196,15 +228,22 @@ val min : 'a list -> 'a
     [Pervasives.compare] *)
 
 val sum : int list -> int
-(** [sum l] returns the sum of the integers of [l] 
+(** [sum l] returns the sum of the integers of [l]
     @raise Invalid_argument on the empty list.
  *)
 
 val fsum : float list -> float
-(** [fsum l] returns the sum of the floats of [l] 
+(** [fsum l] returns the sum of the floats of [l]
     @raise Invalid_argument on the empty list.
  *)
 
+val kahan_sum : float list -> float
+(** [kahan_sum l] returns a numerically-accurate sum of the floats of
+    [l]. See {!BatArray.fsum} for more details.
+
+    @since 2.2.0
+*)
+
 val min_max : ?cmp:('a -> 'a -> int) -> 'a list -> 'a * 'a
 (** [min_max l] returns the pair (smallest, largest) from [l] as judged by
     [Pervasives.compare] (by default). You can provide another
@@ -254,22 +293,26 @@ val mem : 'a -> 'a list -> bool
 (** [mem a l] is true if and only if [a] is equal
     to an element of [l]. *)
 
+val mem_cmp : ('a -> 'a -> int) -> 'a -> 'a list -> bool
+(** Same as {!List.mem}, but the comparator function is explicitely
+    provided.
+    @since 2.2.0 *)
+
 val memq : 'a -> 'a list -> bool
 (** Same as {!List.mem}, but uses physical equality instead of structural
     equality to compare list elements. *)
 
-
 (**{7 Unary predicate, One list}*)
 
 val for_all : ('a -> bool) -> 'a list -> bool
-(** [for_all p [a1; ...; an]] checks if all elements of the list
+(** [for_all p [a0; a1; ...; an]] checks if all elements of the list
     satisfy the predicate [p]. That is, it returns
-    [(p a1) && (p a2) && ... && (p an)]. *)
+    [(p a0) && (p a1) && ... && (p an)]. *)
 
 val exists : ('a -> bool) -> 'a list -> bool
-(** [exists p [a1; ...; an]] checks if at least one element of
+(** [exists p [a0; a1; ...; an]] checks if at least one element of
     the list satisfies the predicate [p]. That is, it returns
-    [(p a1) || (p a2) || ... || (p an)]. *)
+    [(p a0) || (p a1) || ... || (p an)]. *)
 
 (**{7 Binary predicate, Two lists}*)
 
@@ -285,6 +328,13 @@ val exists2 : ('a -> 'b -> bool) -> 'a list -> 'b list -> bool
     @raise Invalid_argument if the two lists have
     different lengths. *)
 
+val subset : ('a -> 'b -> int) -> 'a list -> 'b list -> bool
+(** [subset cmp l l'] check if all elements of the list [l]
+    is contained in the list [l'] by applying [cmp] as comparator.
+
+    @since 2.2.0
+*)
+
 
 (**{6 List searching}*)
 
@@ -319,12 +369,29 @@ val filter : ('a -> bool) -> 'a list -> 'a list
     that satisfy the predicate [p].  The order of the elements
     in the input list is preserved.  *)
 
+val filteri : (int -> 'a -> bool) -> 'a list -> 'a list
+(** [filter p [a0; a1; ...; an]] returns all the elements [ai] of index [i]
+    that satisfy the predicate [p i ai].  The order of the elements
+    in the input list is preserved.
+
+    @since 2.2.0
+ *)
+
 val filter_map : ('a -> 'b option) -> 'a list -> 'b list
 (** [filter_map f l] calls [(f a0) (f a1).... (f an)] where [a0,a1..an] are
     the elements of [l]. It returns the list of elements [bi] such as
     [f ai = Some bi] (when [f] returns [None], the corresponding element of
     [l] is discarded). *)
 
+val filteri_map : (int -> 'a -> 'b option) -> 'a list -> 'b list
+(** [filter_map f l] calls [(f 0 a0) (f 1 a1).... (f n an)] where [a0,a1..an] are
+    the elements of [l]. It returns the list of elements [bi] such as
+    [f ai = Some bi] (when [f] returns [None], the corresponding element of
+    [l] is discarded).
+
+    @since 2.2.0
+*)
+
 val find_all : ('a -> bool) -> 'a list -> 'a list
 (** [find_all] is another name for {!List.filter}. *)
 
@@ -452,6 +519,21 @@ val modify_opt : 'a -> ('b option -> 'b option) -> ('a * 'b) list -> ('a * 'b) l
 
 (** {6 List transformations}*)
 
+val modify_at : int -> ('a -> 'a) -> 'a list -> 'a list
+(** [modify_at n f l] returns the same list as [l]
+    but with nth-value [a] replaced with [f a].
+
+    @raise Invalid_argument if the index is outside of [l] bounds
+    @since 2.3.0 *)
+
+val modify_opt_at : int -> ('a -> 'a option) -> 'a list -> 'a list
+(** [modify_at_opt n f l] returns the same list as [l] but with
+    nth-value [a] removed if [f a] is [None], and replaced by [v] if
+    it is [Some v].
+
+    @raise Invalid_argument if the index is outside of [l] bounds
+    @since 2.3.0 *)
+
 val split_at : int -> 'a list -> 'a list * 'a list
 (** [split_at n l] returns two lists [l1] and [l2], [l1] containing the
     first [n] elements of [l] and [l2] the others. @raise Invalid_argument if
@@ -469,6 +551,14 @@ val remove_if : ('a -> bool) -> 'a list -> 'a list
 (** [remove_if cmp l] is similar to [remove], but with [cmp] used
     instead of ( = ). *)
 
+val remove_at : int -> 'a list -> 'a list
+(** [remove_at i l] returns the list [l] without the element at index [i].
+    @raise Invalid_argument if [i] is outside of [l] size bounds.
+
+    @since 2.3.0
+
+*)
+
 val remove_all : 'a list -> 'a -> 'a list
 (** [remove_all l x] is similar to [remove] but removes all elements that
     are equal to [x] and not only the first one. *)
@@ -477,10 +567,25 @@ val take : int -> 'a list -> 'a list
 (** [take n l] returns up to the [n] first elements from list [l], if
     available. *)
 
+val ntake : int -> 'a list -> 'a list list
+(** [ntake n l] cuts [l] into lists of size at most [n].
+    [n] must be > 0.
+    @raise Invalid_argument if [n] <= 0.
+    Each list in the result has size n, except the last
+    one which may have fewer elements in case [l] was too short.
+    Example: [ntake 2 [1; 2; 3; 4; 5] = [[1; 2]; [3; 4]; [5]]]
+
+    @since 2.2.0 *)
+
 val drop : int -> 'a list -> 'a list
 (** [drop n l] returns [l] without the first [n] elements, or the empty
     list if [l] have less than [n] elements. *)
 
+val takedrop : int -> 'a list -> 'a list * 'a list
+(** [take_drop n l] is equivalent to [(take n l, drop n l)]
+    but is done in one pass.
+    @since 2.2.0 *)
+
 val take_while : ('a -> bool) -> 'a list -> 'a list
 (** [take_while p xs] returns the (possibly empty) longest prefix of
     elements of [xs] that satisfy the predicate [p].*)
@@ -488,13 +593,13 @@ val take_while : ('a -> bool) -> 'a list -> 'a list
 val drop_while : ('a -> bool) -> 'a list -> 'a list
 (** [drop_while p xs] returns the suffix remaining after
     [take_while p xs]. *)
-    
+
 val span : ('a -> bool) -> 'a list -> 'a list * 'a list
-(** [span], applied to a predicate [p] and a list [xs], returns a 
-    tuple where first element is longest prefix (possibly empty) of xs 
+(** [span], applied to a predicate [p] and a list [xs], returns a
+    tuple where first element is longest prefix (possibly empty) of xs
     of elements that satisfy p and second element is the remainder of
     the list. This is equivalent to [(take_while p xs, drop_while p xs)],
-    but is done in one pass. 
+    but is done in one pass.
 
     @since 2.1
 *)
@@ -503,14 +608,14 @@ val nsplit : ('a -> bool) -> 'a list -> 'a list list
 (** [nsplit], applied to a predicate [p] and a list [xs], returns a
     list of lists. [xs] is split when [p x] is true and [x] is excluded
     from the result.
-    
+
     If elements that satisfy [p] are consecutive, or at the beginning
     or end of the input list, the output list will contain empty lists
     marking their position. For example,
     [split (fun n -> n<0) [-1;2;-2;-3;4;-5]] is [[[];[2];[];[4];[]]].
     This is consistent with the behavior of [String.nsplit], where
     [String.nsplit ";" "1;2;;3;" = ["1";"2";"";"3";""]].
-    
+
     Note that for any [xss : 'a list list] and [sep : 'a], we always have
     that [flatten (interleave [sep] (nsplit ((=) sep) xss))] is [xss].
 
@@ -518,14 +623,14 @@ val nsplit : ('a -> bool) -> 'a list -> 'a list list
 *)
 
 val group_consecutive : ('a -> 'a -> bool) -> 'a list -> 'a list list
-(** The [group_consecutive] function takes a list and returns a list of lists such 
-    that the concatenation of the result is equal to the argument. Moreover, each 
-    sublist in the result contains only equal elements. For example, 
+(** The [group_consecutive] function takes a list and returns a list of lists such
+    that the concatenation of the result is equal to the argument. Moreover, each
+    sublist in the result contains only equal elements. For example,
     [group_consecutive (=) [3;3;4;3;3] =  [[3;3];[4];[3;3]]].
 
-    {b Note:} In the next major version, this function is intended to replace the 
+    {b Note:} In the next major version, this function is intended to replace the
     current [group], which also sorts its input before grouping, and which will
-    therefore be renamed into something more pertinent, such as [classify], 
+    therefore be renamed into something more pertinent, such as [classify],
     [regroup], or [group_sort].
 
     @since 2.1
@@ -622,13 +727,18 @@ val merge : ('a -> 'a -> int) -> 'a list -> 'a list -> 'a list
     Not tail-recursive (sum of the lengths of the arguments).
 *)
 
-val sort_unique : ('a -> 'a -> int) -> 'a list -> 'a list
-(** [sort_unique cmp l] returns the list [l] sorted and without any duplicate
-    element. [cmp] is a usual comparison function providing total order.
+val sort_uniq : ('a -> 'a -> int) -> 'a list -> 'a list
+(** [sort_uniq cmp l] returns the list [l] sorted and without any
+    duplicate element. [cmp] is a usual comparison function providing
+    total order.
 
     This function takes O(n log n) time.
+
+    @since 2.3.0
 *)
 
+val sort_unique : ('a -> 'a -> int) -> 'a list -> 'a list
+(** synonym for [sort_uniq] *)
 
 
 (** {6 Utilities}*)
@@ -643,7 +753,7 @@ val group : ('a -> 'a -> int) -> 'a list -> 'a list list
     For example [group cmp [f;c;b;e;d;a]] can give [[[a;b];[c];[d;e;f]]] if
     following conditions are met:
     [cmp a b = 0], [cmp b c = -1], [cmp c d = -1], [cmp d e = 0],...
-    
+
     See the note on [group_consecutive].
 *)
 
@@ -812,6 +922,7 @@ module Labels : sig
   val exists : f:('a -> bool) -> 'a list -> bool
   val for_all2 : f:('a -> 'b -> bool) -> 'a list -> 'b list -> bool
   val exists2 : f:('a -> 'b -> bool) -> 'a list -> 'b list -> bool
+  val subset : cmp:('a -> 'b -> int) -> 'a list -> 'b list -> bool
   val find : f:('a -> bool) -> 'a list -> 'a
   val find_exn : f:('a -> bool) -> exn -> 'a list -> 'a
   val findi : f:(int -> 'a -> bool) -> 'a list -> (int * 'a)
