@@ -1,3 +1,4 @@
+# 1 "src/batPervasives.mliv"
 (*
  * BatPervasives - Additional functions
  * Copyright (C) 1996 Xavier Leroy
@@ -394,8 +395,8 @@ val undefined : ?message:string -> 'a -> 'b
       "Undefined". Optional argument [message] permits the
       customization of the error message.*)
 
-
  external ( @@ ) : ('a -> 'b) -> 'a -> 'b = "%apply"
+# 399 "src/batPervasives.mliv"
 
 (** Function application. [f @@ x] is equivalent to [f x].
     However, it binds less tightly (between [::] and [=],[<],[>],etc)
@@ -410,8 +411,8 @@ val ( % ) : ('a -> 'b) -> ('c -> 'a) -> 'c -> 'b
       Examples: the following are equivalent:
       [f (g (h x))], [f @@ g @@ h x], [f % g % h @@ x]. *)
 
-
  external (|>) : 'a -> ('a -> 'b) -> 'b = "%revapply"
+# 415 "src/batPervasives.mliv"
 (** The "pipe": function application. [x |> f] is equivalent to [f x].
 
     This operator is commonly used to write a function composition by
@@ -430,7 +431,7 @@ val ( % ) : ('a -> 'b) -> ('c -> 'a) -> 'c -> 'b
 
 val ( %> ) : ('a -> 'b) -> ('b -> 'c) -> 'a -> 'c
 (** Piping function composition. [f %> g] is [fun x -> g (f x)].
-    Whereas [f % g] applies [g] first and [f] second, [f @> g]
+    Whereas [f % g] applies [g] first and [f] second, [f %> g]
     applies [f], then [g].
     Note that it plays well with pipes, so for instance
     [x |> f %> g %> h |> i %> j] yields the expected result...
