@@ -83,6 +83,13 @@ sig
   (** [remove x s] returns a set containing all elements of [s],
       except [x]. If [x] was not in [s], [s] is returned unchanged. *)
 
+  val update: elt -> elt -> t -> t
+  (** [update x y s] replace [x] by [y] in [s].
+      [update] is faster when [x] compares equal to [y] according
+      to the comparison function used by your set.
+      @raise Not_found if [x] is not in [s].
+      @since 2.4 *)
+
   val union: t -> t -> t
   (** Set union. *)
 
@@ -121,6 +128,14 @@ sig
       The elements of [s] are presented to [f] in increasing order
       with respect to the ordering over the type of the elements. *)
 
+  val at_rank_exn: int -> t -> elt
+  (** [at_rank_exn i s] returns element at rank [i] in [s], that is
+      the [i]-th element in increasing order
+      (the [0]-th element being the smallest element of [s]).
+      @raise Not_found if [s = empty].
+      @raise Invalid_argument error_message if [i < 0 || i >= cardinal s]
+      @since 2.4 *)
+
   val map: (elt -> elt) -> t -> t
   (** [map f x] creates a new set with elements [f a0],
       [f a1]... [f aN], where [a0],[a1]..[aN] are the
@@ -200,12 +215,36 @@ sig
   (** Alias for [elements].
       @since 2.2.0 *)
 
+  val to_array: t -> elt array
+  (** Same as [to_list] but with an array instead of a list.
+      @since 2.4 *)
+
   val min_elt: t -> elt
   (** Return the smallest element of the given set
       (with respect to the [Ord.compare] ordering).
 
     @raise Not_found if the set is empty. *)
 
+  val pop_min: t -> elt * t
+  (** Returns the smallest element of the given set
+      along with the rest of the set.
+      Semantically equivalent and faster than
+
+      [let mini = min_elt s in (mini, remove mini s)]
+
+      @raise Not_found if the set is empty.
+      @since 2.4 *)
+
+  val pop_max: t -> elt * t
+  (** Returns the biggest element of the given set
+      along with the rest of the set.
+      Semantically equivalent and faster than
+
+      [let maxi = max_elt s in (maxi, remove maxi s)]
+
+      @raise Not_found if the set is empty.
+      @since 2.4 *)
+
   val max_elt: t -> elt
   (** Same as {!Set.S.min_elt}, but returns the largest element of the
       given set. *)
@@ -239,6 +278,12 @@ sig
       @since 2.3.0
   *)
 
+  val of_array: elt array -> t
+  (** builds a set from the given array.
+
+      @since 2.4
+  *)
+
 
   (** {6 Boilerplate code}*)
 
@@ -248,6 +293,18 @@ sig
     ('a BatInnerIO.output -> elt -> unit) ->
     'a BatInnerIO.output -> t -> unit
 
+  (** {7 Infix operators} *)
+
+  module Infix : sig
+    val (<--) : t -> elt -> t (** insertion *)
+    val (<.) : t -> t -> bool  (** strict subset *)
+    val (>.) : t -> t -> bool  (** strict superset *)
+    val (<=.) : t -> t -> bool (** subset *)
+    val (>=.) : t -> t -> bool (** superset *)
+    val (-.) : t -> t -> t     (** difference *)
+    val (&&.) : t -> t -> t   (** intersection *)
+    val (||.) : t -> t -> t   (** union *)
+  end
 
   (** {6 Override modules}*)
 
@@ -310,6 +367,14 @@ module Make (Ord : OrderedType) : S with type elt = Ord.t
     @documents Set.Make
 *)
 
+
+module Make2(O1 : OrderedType) (O2 : OrderedType) : sig
+  module Product : S with type elt = O1.t * O2.t
+
+  val cartesian_product : Make(O1).t -> Make(O2).t -> Product.t
+  (** cartesian product of the two sets *)
+end
+
 (** {6 Polymorphic sets}
 
     The definitions below describe the polymorphic set interface.
@@ -359,6 +424,13 @@ val remove: 'a -> 'a t -> 'a t
 (** [remove x s] returns a set containing all elements of [s],
     except [x]. If [x] was not in [s], [s] is returned unchanged. *)
 
+val update: 'a -> 'a -> 'a t -> 'a t
+(** [update x y s] replace [x] by [y] in [s].
+    [update] is faster when [x] compares equal to [y] according
+    to the comparison function used by your set.
+    @raise Not_found if [x] is not in [s].
+    @since 2.4 *)
+
 val union: 'a t -> 'a t -> 'a t
 (** [union s t] returns the union of [s] and [t] - the set containing
     all elements in either [s] and [t].  The returned set uses [t]'s
@@ -400,6 +472,14 @@ val iter: ('a -> unit) -> 'a t -> unit
     The elements of [s] are presented to [f] in increasing order
     with respect to the ordering over the type of the elements. *)
 
+val at_rank_exn: int -> 'a t -> 'a
+(** [at_rank_exn i s] returns element at rank [i] in [s], that is
+    the [i]-th element in increasing order
+    (the [0]-th element being the smallest element of [s]).
+    @raise Not_found if [s = empty].
+    @raise Invalid_argument error_message if [i < 0 || i >= cardinal s]
+    @since 2.4 *)
+
 val map: ('a -> 'b) -> 'a t -> 'b t
 (** [map f x] creates a new set with elements [f a0],
     [f a1]... [f aN], where [a0], [a1], ..., [aN] are the
@@ -487,10 +567,34 @@ val to_list: 'a t -> 'a list
 (** Alias for [elements].
     @since 2.2.0 *)
 
+val to_array: 'a t -> 'a array
+(** Same as [to_list] but with an array instead of a list.
+    @since 2.4 *)
+
 val min_elt : 'a t -> 'a
 (** returns the smallest element of the set.
     @raise Invalid_argument if given an empty set. *)
 
+val pop_min: 'a t -> 'a * 'a t
+(** Returns the smallest element of the given set
+    along with the rest of the set.
+    Semantically equivalent and faster than
+
+    [let mini = min_elt s in (mini, remove mini s)]
+
+    @raise Not_found if the set is empty.
+    @since 2.4 *)
+
+val pop_max: 'a t -> 'a * 'a t
+(** Returns the biggest element of the given set
+    along with the rest of the set.
+    Semantically equivalent and faster than
+
+    [let maxi = max_elt s in (maxi, remove maxi s)]
+
+    @raise Not_found if the set is empty.
+    @since 2.4 *)
+
 val max_elt : 'a t -> 'a
 (** returns the largest element of the set.
     @raise Invalid_argument if given an empty set.*)
@@ -524,6 +628,10 @@ val of_list: 'a list -> 'a t
 (** builds a set from the given list, using the default comparison
     function *)
 
+val of_array: 'a array -> 'a t
+(** builds a set from the given array, using the default comparison
+    function *)
+
 (** {6 Boilerplate code}*)
 
 
@@ -533,6 +641,18 @@ val print :  ?first:string -> ?last:string -> ?sep:string ->
   ('a BatInnerIO.output -> 'c -> unit) ->
   'a BatInnerIO.output -> 'c t -> unit
 
+(** {7 Infix operators} *)
+
+module Infix : sig
+  val (<--) : 'a t -> 'a -> 'a t (** insertion *)
+  val (<.) : 'a t -> 'a t -> bool  (** strict subset *)
+  val (>.) : 'a t -> 'a t -> bool  (** strict superset *)
+  val (<=.) : 'a t -> 'a t -> bool (** subset *)
+  val (>=.) : 'a t -> 'a t -> bool (** superset *)
+  val (-.) : 'a t -> 'a t -> 'a t     (** difference *)
+  val (&&.) : 'a t -> 'a t -> 'a t   (** intersection *)
+  val (||.) : 'a t -> 'a t -> 'a t   (** union *)
+end
 
 (** {6 Incubator} *)
 module Incubator : sig
@@ -588,6 +708,11 @@ module PSet : sig
   val mem: 'a -> 'a t -> bool
   (** [mem x s] tests whether [x] belongs to the set [s]. *)
 
+  val find : 'a -> 'a t -> 'a
+  (** [find x s] returns the element in s that tests equal to [x] under its comparison function.
+      @raise Not_found if no element is equal
+  *)
+
   val add: 'a -> 'a t -> 'a t
   (** [add x s] returns a set containing all elements of [s],
       plus [x]. If [x] was already in [s], [s] is returned unchanged. *)
@@ -596,6 +721,13 @@ module PSet : sig
   (** [remove x s] returns a set containing all elements of [s],
       except [x]. If [x] was not in [s], [s] is returned unchanged. *)
 
+  val update: 'a -> 'a -> 'a t -> 'a t
+  (** [update x y s] replace [x] by [y] in [s].
+      [update] is faster when [x] compares equal to [y] according
+      to the comparison function used by your set.
+      @raise Not_found if [x] is not in [s].
+      @since 2.4 *)
+
   val union: 'a t -> 'a t -> 'a t
   (** [union s t] returns the union of [s] and [t] - the set containing
       all elements in either [s] and [t].  The returned set uses [t]'s
@@ -636,6 +768,14 @@ module PSet : sig
       The elements of [s] are presented to [f] in increasing order
       with respect to the ordering over the type of the elements. *)
 
+  val at_rank_exn: int -> 'a t -> 'a
+  (** [at_rank_exn i s] returns element at rank [i] in [s], that is
+      the [i]-th element in increasing order
+      (the [0]-th element being the smallest element of [s]).
+      @raise Not_found if [s = empty].
+      @raise Invalid_argument error_message if [i < 0 || i >= cardinal s]
+      @since 2.4 *)
+
   (* under-specified; either give a 'b comparison,
      or keep ('a -> 'a) (preferred choice) *)
   val map: ('a -> 'b) -> 'a t -> 'b t
@@ -718,10 +858,34 @@ module PSet : sig
   val to_list: 'a t -> 'a list
   (** Alias for [elements]. *)
 
+  val to_array: 'a t -> 'a array
+  (** Same as [to_list] but with an array instead of a list.
+      @since 2.4 *)
+
   val min_elt : 'a t -> 'a
   (** returns the smallest element of the set.
       @raise Invalid_argument if given an empty set. *)
 
+  val pop_min: 'a t -> 'a * 'a t
+  (** Returns the smallest element of the given set
+      along with the rest of the set.
+      Semantically equivalent and faster than
+
+      [let mini = min_elt s in (mini, remove mini s)]
+
+      @raise Not_found if the set is empty.
+      @since 2.4 *)
+
+  val pop_max: 'a t -> 'a * 'a t
+  (** Returns the biggest element of the given set
+      along with the rest of the set.
+      Semantically equivalent and faster than
+
+      [let maxi = max_elt s in (maxi, remove maxi s)]
+
+      @raise Not_found if the set is empty.
+      @since 2.4 *)
+
   val max_elt : 'a t -> 'a
   (** returns the largest element of the set.
       @raise Invalid_argument if given an empty set.*)
@@ -747,6 +911,10 @@ module PSet : sig
   (** builds a set from the given list, using the default comparison
       function *)
 
+  val of_array: 'a array -> 'a t
+  (** builds a set from the given array, using the default comparison
+      function *)
+
   (** {6 Boilerplate code}*)
 
 
@@ -756,6 +924,19 @@ module PSet : sig
     ('a BatInnerIO.output -> 'c -> unit) ->
     'a BatInnerIO.output -> 'c t -> unit
 
+  (** {7 Infix operators} *)
+
+  module Infix : sig
+    val (<--) : 'a t -> 'a -> 'a t (** insertion *)
+    val (<.) : 'a t -> 'a t -> bool  (** strict subset *)
+    val (>.) : 'a t -> 'a t -> bool  (** strict superset *)
+    val (<=.) : 'a t -> 'a t -> bool (** subset *)
+    val (>=.) : 'a t -> 'a t -> bool (** superset *)
+    val (-.) : 'a t -> 'a t -> 'a t     (** difference *)
+    val (&&.) : 'a t -> 'a t -> 'a t   (** intersection *)
+    val (||.) : 'a t -> 'a t -> 'a t   (** union *)
+  end
+
   (** get the comparison function used for a polymorphic map *)
   val get_cmp : 'a t -> ('a -> 'a -> int)
 
