@@ -1,3 +1,4 @@
+# 1 "src/batSys.mliv"
 (*
  * BatSys - additional and modified functions for System
  * Copyright (C) 1996 Xavier Leroy
@@ -65,7 +66,9 @@ external getenv : string -> string = "caml_sys_getenv"
 external command : string -> int = "caml_sys_system_command"
 (** Execute the given shell command and return its exit code. *)
 
-external time : unit -> float = "caml_sys_time"
+external time : unit -> (float [@unboxed]) =
+  "caml_sys_time" "caml_sys_time_unboxed" [@@noalloc]
+# 71 "src/batSys.mliv"
 (** Return the processor time, in seconds, used by the program
     since the beginning of execution. *)
 
@@ -106,11 +109,20 @@ val win32 : bool
 val cygwin : bool
 (** True if [Sys.os_type = "Cygwin"].
     @since 4.01.0 *)
+# 111 "src/batSys.mliv"
 
 val word_size : int
 (** Size of one word on the machine currently executing the OCaml
     program, in bits: 32 or 64. *)
 
+val int_size : int
+(** Size of an int.  It is 31 bits (resp. 63 bits) when using the
+    OCaml compiler on a 32 bits (resp. 64 bits) platform.  It may
+    differ for other compilers, e.g. it is 32 bits when compiling to
+    JavaScript.
+    @since 2.5.0 and OCaml 4.03.0 *)
+# 122 "src/batSys.mliv"
+
 val big_endian : bool
 (** Whether the machine currently executing the OCaml program is big-endian.
     @since 4.00.0 *)
@@ -123,6 +135,18 @@ val max_array_length : int
     array is [max_array_length/2] on 32-bit machines and
     [max_array_length] on 64-bit machines. *)
 
+external runtime_variant : unit -> string = "caml_runtime_variant"
+(** Return the name of the runtime variant the program is running on.
+    This is normally the argument given to [-runtime-variant] at compile
+    time, but for byte-code it can be changed after compilation.
+    @since 2.5.0 and OCaml 4.03.0 *)
+
+external runtime_parameters : unit -> string = "caml_runtime_parameters"
+(** Return the value of the runtime parameters, in the same format
+    as the contents of the [OCAMLRUNPARAM] environment variable.
+    @since 2.5.0 and OCaml 4.03.0 *)
+# 145 "src/batSys.mliv"
+
 
 (** {6 Signal handling} *)
 
@@ -215,6 +239,34 @@ val sigvtalrm : int
 val sigprof : int
 (** Profiling interrupt *)
 
+val sigbus : int
+(** Bus error
+    @since 2.5.0 *)
+
+val sigpoll : int
+(** Pollable event
+    @since 2.5.0 *)
+
+val sigsys : int
+(** Bad argument to routine
+    @since 2.5.0 *)
+
+val sigtrap : int
+(** Trace/breakpoint trap
+    @since 2.5.0 *)
+
+val sigurg : int
+(** Urgent condition on socket
+    @since 2.5.0 *)
+
+val sigxcpu : int
+(** Timeout in cpu time
+    @since 2.5.0 *)
+
+val sigxfsz : int
+(** File size limit exceeded
+    @since 2.5.0 *)
+
 
 exception Break
 (** Exception raised on interactive interrupt if {!Sys.catch_break}
@@ -240,3 +292,41 @@ val ocaml_version : string;;
 val files_of: string -> string BatEnum.t
     (**As {!readdir} but the results are presented as an enumeration
        of names.*)
+
+val enable_runtime_warnings: bool -> unit
+(** Control whether the OCaml runtime system can emit warnings
+    on stderr.  Currently, the only supported warning is triggered
+    when a channel created by [open_*] functions is finalized without
+    being closed.  Runtime warnings are enabled by default.
+    @since 2.5.0 and OCaml 4.03 *)
+# 298 "src/batSys.mliv"
+
+val runtime_warnings_enabled: unit -> bool
+(** Return whether runtime warnings are currently enabled.
+    @since 2.5.0 and OCaml 4.03 *)
+# 302 "src/batSys.mliv"
+
+(** {6 Optimization} *)
+
+external opaque_identity : 'a -> 'a = "%opaque"
+# 307 "src/batSys.mliv"
+(** For the purposes of optimization, [opaque_identity] behaves like an
+    unknown (and thus possibly side-effecting) function.
+
+    At runtime, [opaque_identity] disappears altogether.
+
+    A typical use of this function is to prevent pure computations from being
+    optimized away in benchmarking loops.  For example:
+    {[
+      for _round = 1 to 100_000 do
+        ignore (Sys.opaque_identity (my_pure_computation ()))
+      done
+    ]}
+
+    The compiler primitive was added to OCaml 4.03, but we emulate it
+    under 4.02 using the -opaque compilation flag. There is no easy
+    way for Batteries to emulate it correctly under older OCaml
+    versions.
+
+    @since 2.5.0 and OCaml 4.02
+ *)
