@@ -1,3 +1,4 @@
+# 1 "src/batUnix.mliv"
 (*
  * BatUnix - additional and modified functions for Unix and Unix-compatible systems.
  * Copyright (C) 1996 Xavier Leroy
@@ -216,6 +217,13 @@ val system : string -> process_status
     etc. The result [WEXITED 127] indicates that the shell couldn't
     be executed. *)
 
+val run_and_read : string -> process_status * string
+(** [(stat, output) = run_and_read cmd] run the command [cmd]
+    (via Unix.system) then return its exit status [stat] and
+    output string [output] as read from its standard output (which
+    was redirected to a temporary file).
+    @since 2.4 *)
+
 val getpid : unit -> int
 (** Return the pid of the process. *)
 
@@ -265,6 +273,7 @@ type open_flag = Unix.open_flag =
                                     descriptor returned by {!openfile}
 
                                     Since OCaml 4.1 *)
+# 275 "src/batUnix.mliv"
 (** The flags to {!Unix.openfile}. *)
 
 
@@ -757,11 +766,56 @@ val create_process_env :
 
 
 (** {6 Symbolic links} *)
+val symlink : ?to_dir:bool -> string -> string -> unit
+(** [symlink ?to_dir source dest] creates the file [dest] as
+   a symbolic link to the file [source]. On Windows, [~to_dir]
+   indicates if the symbolic link points to a directory or a file;
+   if omitted, [symlink] examines [source] using [stat] and picks
+   appropriately, if [source] does not exist then [false] is
+   assumed (for this reason, it is recommended that the [~to_dir]
+   parameter be specified in new code). On Unix, [~to_dir]
+   ignored.
 
+   Windows symbolic links are available in Windows Vista
+   onwards. There are some important differences between Windows
+   symlinks and their POSIX counterparts.
 
-val symlink : string -> string -> unit
-(** [symlink source dest] creates the file [dest] as a symbolic link
-    to the file [source]. *)
+   Windows symbolic links come in two flavours: directory and
+   regular, which designate whether the symbolic link points to
+   a directory or a file. The type must be correct - a directory
+   symlink which actually points to a file cannot be selected with
+   chdir and a file symlink which actually points to a directory
+   cannot be read or written (note that Cygwin's emulation layer
+   ignores this distinction).
+
+   When symbolic links are created to existing targets, this
+   distinction doesn't matter and [symlink] will automatically
+   create the correct kind of symbolic link. The distinction
+   matters when a symbolic link is created to a non-existent
+   target.
+
+   The other caveat is that by default symbolic links are
+   a privileged operation. Administrators will always need to be
+   running elevated (or with UAC disabled) and by default normal
+   user accounts need to be granted the
+   SeCreateSymbolicLinkPrivilege via Local Security Policy
+   (secpol.msc) or via Active Directory.
+
+   {!has_symlink} can be used to check that a process is able to
+   create symbolic links.
+
+   @since 4.03 the optional argument ?to_dir was added in 4.03
+*)
+# 810 "src/batUnix.mliv"
+
+val has_symlink : unit -> bool
+(** Returns [true] if the user is able to create symbolic links. On Windows,
+   this indicates that the user not only has the SeCreateSymbolicLinkPrivilege
+   but is also running elevated, if necessary. On other platforms, this is
+   simply indicates that the symlink system call is available.
+
+   @since 2.5.0 and OCaml 4.03 *)
+# 818 "src/batUnix.mliv"
 
 val readlink : string -> string
 (** Read the contents of a link. *)
@@ -915,6 +969,12 @@ val alarm : int -> int
 val sleep : int -> unit
 (** Stop execution for the given number of seconds. *)
 
+val sleepf : float -> unit
+(** Stop execution for the given number of seconds.  Like [sleep],
+    but fractions of seconds are supported.
+    @since 2.5.0 and OCaml 4.03 *)
+# 975 "src/batUnix.mliv"
+
 val times : unit -> process_times
 (** Return the execution times of the process. *)
 
